# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.hub_spot_actor_id_response import HubSpotActorIdResponse

class TestHubSpotActorIdResponse(unittest.TestCase):
    """HubSpotActorIdResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HubSpotActorIdResponse:
        """Test HubSpotActorIdResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `HubSpotActorIdResponse`
        """
        model = HubSpotActorIdResponse()
        if include_optional:
            return HubSpotActorIdResponse(
                actor_id = '',
                actor_email = ''
            )
        else:
            return HubSpotActorIdResponse(
                actor_id = '',
                actor_email = '',
        )
        """

    def testHubSpotActorIdResponse(self):
        """Test HubSpotActorIdResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.tags_api import TagsApi


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TagsApi()

    def tearDown(self) -> None:
        pass

    def test_create_tag(self) -> None:
        """Test case for create_tag

        Create Tag
        """
        pass

    def test_delete_tag(self) -> None:
        """Test case for delete_tag

        Delete Tag
        """
        pass

    def test_search_tags(self) -> None:
        """Test case for search_tags

        Search Tags
        """
        pass

    def test_update_tag(self) -> None:
        """Test case for update_tag

        Update Tag
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.plan_response import PlanResponse

class TestPlanResponse(unittest.TestCase):
    """PlanResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlanResponse:
        """Test PlanResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlanResponse`
        """
        model = PlanResponse()
        if include_optional:
            return PlanResponse(
                plans = {
                    'key' : [
                        flowhunt.models.plan_list_item_response.PlanListItemResponse(
                            product_id = '', 
                            price_id = '', 
                            currency = '', 
                            amount_monthly = 56, 
                            amount_yearly = 56, 
                            recurring = True, 
                            name = '', 
                            description = '', 
                            popular = True, 
                            monthly_credits = 56, 
                            features = [
                                flowhunt.models.feature_response.FeatureResponse(
                                    name = '', 
                                    available = True, )
                                ], 
                            subscription_plan = 'S', 
                            self_hosted = True, 
                            addon = True, 
                            addon_type = '', )
                        ]
                    }
            )
        else:
            return PlanResponse(
                plans = {
                    'key' : [
                        flowhunt.models.plan_list_item_response.PlanListItemResponse(
                            product_id = '', 
                            price_id = '', 
                            currency = '', 
                            amount_monthly = 56, 
                            amount_yearly = 56, 
                            recurring = True, 
                            name = '', 
                            description = '', 
                            popular = True, 
                            monthly_credits = 56, 
                            features = [
                                flowhunt.models.feature_response.FeatureResponse(
                                    name = '', 
                                    available = True, )
                                ], 
                            subscription_plan = 'S', 
                            self_hosted = True, 
                            addon = True, 
                            addon_type = '', )
                        ]
                    },
        )
        """

    def testPlanResponse(self):
        """Test PlanResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class TrackingEventData(BaseModel):
    """
    Value object for tracking event data
    """ # noqa: E501
    key: StrictStr
    value_text: Optional[StrictStr] = None
    value_number: Optional[Union[StrictFloat, StrictInt]] = None
    value_boolean: Optional[StrictBool] = None
    value_datetime: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["key", "value_text", "value_number", "value_boolean", "value_datetime"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TrackingEventData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if value_text (nullable) is None
        # and model_fields_set contains the field
        if self.value_text is None and "value_text" in self.model_fields_set:
            _dict['value_text'] = None

        # set to None if value_number (nullable) is None
        # and model_fields_set contains the field
        if self.value_number is None and "value_number" in self.model_fields_set:
            _dict['value_number'] = None

        # set to None if value_boolean (nullable) is None
        # and model_fields_set contains the field
        if self.value_boolean is None and "value_boolean" in self.model_fields_set:
            _dict['value_boolean'] = None

        # set to None if value_datetime (nullable) is None
        # and model_fields_set contains the field
        if self.value_datetime is None and "value_datetime" in self.model_fields_set:
            _dict['value_datetime'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TrackingEventData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "key": obj.get("key"),
            "value_text": obj.get("value_text"),
            "value_number": obj.get("value_number"),
            "value_boolean": obj.get("value_boolean"),
            "value_datetime": obj.get("value_datetime")
        })
        return _obj





# flake8: noqa

# import apis into api package
from flowhunt.api.api_keys_api import ApiKeysApi
from flowhunt.api.billing_api import BillingApi
from flowhunt.api.chatbots_api import ChatbotsApi
from flowhunt.api.credits_api import CreditsApi
from flowhunt.api.documents_api import DocumentsApi
from flowhunt.api.fine_tunings_api import FineTuningsApi
from flowhunt.api.flow_assistant_api import FlowAssistantApi
from flowhunt.api.flow_messages_api import FlowMessagesApi
from flowhunt.api.flow_sessions_api import FlowSessionsApi
from flowhunt.api.flow_webhooks_api import FlowWebhooksApi
from flowhunt.api.flows_api import FlowsApi
from flowhunt.api.google_api import GoogleApi
from flowhunt.api.google_ads_api import GoogleAdsApi
from flowhunt.api.health_api import HealthApi
from flowhunt.api.hub_spot_api import HubSpotApi
from flowhunt.api.images_api import ImagesApi
from flowhunt.api.instagram_api import InstagramApi
from flowhunt.api.integrations_api import IntegrationsApi
from flowhunt.api.logs_api import LogsApi
from flowhunt.api.mcp_servers_api import MCPServersApi
from flowhunt.api.media_api import MediaApi
from flowhunt.api.microsoft_outlook_api import MicrosoftOutlookApi
from flowhunt.api.o_auth_api import OAuthApi
from flowhunt.api.observability_driver_api import ObservabilityDriverApi
from flowhunt.api.photo_ai_api import PhotoAIApi
from flowhunt.api.prompts_api import PromptsApi
from flowhunt.api.serp_api import SERPApi
from flowhunt.api.schedules_api import SchedulesApi
from flowhunt.api.secrets_api import SecretsApi
from flowhunt.api.semantic_search_api import SemanticSearchApi
from flowhunt.api.shopify_api import ShopifyApi
from flowhunt.api.slack_api import SlackApi
from flowhunt.api.tags_api import TagsApi
from flowhunt.api.tracking_api import TrackingApi
from flowhunt.api.web_auth_api import WebAuthApi
from flowhunt.api.word_press_api import WordPressApi
from flowhunt.api.workspaces_api import WorkspacesApi
from flowhunt.api.workspaces_sso_api import WorkspacesSSOApi
from flowhunt.api.workspaces_sso_domain_verification_api import WorkspacesSSODomainVerificationApi




# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.document_content import DocumentContent

class TestDocumentContent(unittest.TestCase):
    """DocumentContent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DocumentContent:
        """Test DocumentContent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DocumentContent`
        """
        model = DocumentContent()
        if include_optional:
            return DocumentContent(
                url = '',
                img_url = '',
                status_code = 56,
                created_at = 1.337,
                published_at = 1.337,
                title = '',
                doc_name = '',
                lang = '',
                content_type = '',
                encoding = '',
                apparent_encoding = '',
                description = '',
                content = [
                    [
                        null
                        ]
                    ],
                metadata = {
                    'key' : null
                    },
                alt_content = [
                    ''
                    ],
                content_hash = '',
                author = '',
                channel_id = '',
                channel_url = '',
                channel_title = '',
                duration = 56,
                keywords = [
                    ''
                    ],
                doc_type = 'PDF',
                credits = 56
            )
        else:
            return DocumentContent(
        )
        """

    def testDocumentContent(self):
        """Test DocumentContent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.workspaces_sso_domain_verification_api import WorkspacesSSODomainVerificationApi


class TestWorkspacesSSODomainVerificationApi(unittest.TestCase):
    """WorkspacesSSODomainVerificationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkspacesSSODomainVerificationApi()

    def tearDown(self) -> None:
        pass

    def test_create_domain_verification(self) -> None:
        """Test case for create_domain_verification

        Create Domain Verification
        """
        pass

    def test_delete_domain_verification(self) -> None:
        """Test case for delete_domain_verification

        Delete Domain Verification
        """
        pass

    def test_list_domain_verifications(self) -> None:
        """Test case for list_domain_verifications

        List Domain Verifications
        """
        pass

    def test_verify_domain(self) -> None:
        """Test case for verify_domain

        Verify Domain
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.schedules_api import SchedulesApi


class TestSchedulesApi(unittest.TestCase):
    """SchedulesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SchedulesApi()

    def tearDown(self) -> None:
        pass

    def test_create_schedules(self) -> None:
        """Test case for create_schedules

        Create Schedules
        """
        pass

    def test_delete_schedule(self) -> None:
        """Test case for delete_schedule

        Delete Schedule
        """
        pass

    def test_get_schedule(self) -> None:
        """Test case for get_schedule

        Get Schedule
        """
        pass

    def test_get_schedule_url_details(self) -> None:
        """Test case for get_schedule_url_details

        Get Schedule Url Details
        """
        pass

    def test_get_schedules(self) -> None:
        """Test case for get_schedules

        Get Schedules
        """
        pass

    def test_run_schedule(self) -> None:
        """Test case for run_schedule

        Run Schedule
        """
        pass

    def test_search_schedule_urls(self) -> None:
        """Test case for search_schedule_urls

        Search Schedule Urls
        """
        pass

    def test_update_schedule(self) -> None:
        """Test case for update_schedule

        Update Schedule
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.serp_search_requests import SerpSearchRequests

class TestSerpSearchRequests(unittest.TestCase):
    """SerpSearchRequests unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SerpSearchRequests:
        """Test SerpSearchRequests
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SerpSearchRequests`
        """
        model = SerpSearchRequests()
        if include_optional:
            return SerpSearchRequests(
                requests = [
                    flowhunt.models.serp_search_request.SerpSearchRequest(
                        post_back_url = '', 
                        query = 'liveagent help desk software', 
                        country = '', 
                        location = '', 
                        language = '', 
                        count_urls = 56, )
                    ],
                live_mode = True
            )
        else:
            return SerpSearchRequests(
                requests = [
                    flowhunt.models.serp_search_request.SerpSearchRequest(
                        post_back_url = '', 
                        query = 'liveagent help desk software', 
                        country = '', 
                        location = '', 
                        language = '', 
                        count_urls = 56, )
                    ],
        )
        """

    def testSerpSearchRequests(self):
        """Test SerpSearchRequests"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FlowAssistantAIModel(str, Enum):
    """
    FlowAssistantAIModel
    """

    """
    allowed enum values
    """
    CLAUDE_3_DOT_5_SONNET = 'Claude 3.5 Sonnet'
    CLAUDE_3_DOT_7_SONNET = 'Claude 3.7 Sonnet'
    GPT4_DOT_1 = 'GPT4.1'
    O4_MINI = 'O4 Mini'
    O3_MINI = 'O3 Mini'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FlowAssistantAIModel from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from flowhunt.models.document_type import DocumentType
from typing import Optional, Set
from typing_extensions import Self

class DocumentContent(BaseModel):
    """
    DocumentContent
    """ # noqa: E501
    url: Optional[StrictStr] = None
    img_url: Optional[StrictStr] = None
    status_code: Optional[StrictInt] = None
    created_at: Optional[Union[StrictFloat, StrictInt]] = None
    published_at: Optional[Union[StrictFloat, StrictInt]] = None
    title: Optional[StrictStr] = None
    doc_name: Optional[StrictStr] = None
    lang: Optional[StrictStr] = None
    content_type: Optional[StrictStr] = None
    encoding: Optional[StrictStr] = None
    apparent_encoding: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    content: Optional[List[Annotated[List[Any], Field(min_length=2, max_length=2)]]] = None
    metadata: Optional[Dict[str, Any]] = None
    alt_content: Optional[List[StrictStr]] = None
    content_hash: Optional[StrictStr] = None
    author: Optional[StrictStr] = None
    channel_id: Optional[StrictStr] = None
    channel_url: Optional[StrictStr] = None
    channel_title: Optional[StrictStr] = None
    duration: Optional[StrictInt] = None
    keywords: Optional[List[StrictStr]] = None
    doc_type: Optional[DocumentType] = None
    credits: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["url", "img_url", "status_code", "created_at", "published_at", "title", "doc_name", "lang", "content_type", "encoding", "apparent_encoding", "description", "content", "metadata", "alt_content", "content_hash", "author", "channel_id", "channel_url", "channel_title", "duration", "keywords", "doc_type", "credits"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DocumentContent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict['url'] = None

        # set to None if img_url (nullable) is None
        # and model_fields_set contains the field
        if self.img_url is None and "img_url" in self.model_fields_set:
            _dict['img_url'] = None

        # set to None if status_code (nullable) is None
        # and model_fields_set contains the field
        if self.status_code is None and "status_code" in self.model_fields_set:
            _dict['status_code'] = None

        # set to None if created_at (nullable) is None
        # and model_fields_set contains the field
        if self.created_at is None and "created_at" in self.model_fields_set:
            _dict['created_at'] = None

        # set to None if published_at (nullable) is None
        # and model_fields_set contains the field
        if self.published_at is None and "published_at" in self.model_fields_set:
            _dict['published_at'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if doc_name (nullable) is None
        # and model_fields_set contains the field
        if self.doc_name is None and "doc_name" in self.model_fields_set:
            _dict['doc_name'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if content_type (nullable) is None
        # and model_fields_set contains the field
        if self.content_type is None and "content_type" in self.model_fields_set:
            _dict['content_type'] = None

        # set to None if encoding (nullable) is None
        # and model_fields_set contains the field
        if self.encoding is None and "encoding" in self.model_fields_set:
            _dict['encoding'] = None

        # set to None if apparent_encoding (nullable) is None
        # and model_fields_set contains the field
        if self.apparent_encoding is None and "apparent_encoding" in self.model_fields_set:
            _dict['apparent_encoding'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict['content'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if alt_content (nullable) is None
        # and model_fields_set contains the field
        if self.alt_content is None and "alt_content" in self.model_fields_set:
            _dict['alt_content'] = None

        # set to None if content_hash (nullable) is None
        # and model_fields_set contains the field
        if self.content_hash is None and "content_hash" in self.model_fields_set:
            _dict['content_hash'] = None

        # set to None if author (nullable) is None
        # and model_fields_set contains the field
        if self.author is None and "author" in self.model_fields_set:
            _dict['author'] = None

        # set to None if channel_id (nullable) is None
        # and model_fields_set contains the field
        if self.channel_id is None and "channel_id" in self.model_fields_set:
            _dict['channel_id'] = None

        # set to None if channel_url (nullable) is None
        # and model_fields_set contains the field
        if self.channel_url is None and "channel_url" in self.model_fields_set:
            _dict['channel_url'] = None

        # set to None if channel_title (nullable) is None
        # and model_fields_set contains the field
        if self.channel_title is None and "channel_title" in self.model_fields_set:
            _dict['channel_title'] = None

        # set to None if duration (nullable) is None
        # and model_fields_set contains the field
        if self.duration is None and "duration" in self.model_fields_set:
            _dict['duration'] = None

        # set to None if keywords (nullable) is None
        # and model_fields_set contains the field
        if self.keywords is None and "keywords" in self.model_fields_set:
            _dict['keywords'] = None

        # set to None if doc_type (nullable) is None
        # and model_fields_set contains the field
        if self.doc_type is None and "doc_type" in self.model_fields_set:
            _dict['doc_type'] = None

        # set to None if credits (nullable) is None
        # and model_fields_set contains the field
        if self.credits is None and "credits" in self.model_fields_set:
            _dict['credits'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DocumentContent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "url": obj.get("url"),
            "img_url": obj.get("img_url"),
            "status_code": obj.get("status_code"),
            "created_at": obj.get("created_at"),
            "published_at": obj.get("published_at"),
            "title": obj.get("title"),
            "doc_name": obj.get("doc_name"),
            "lang": obj.get("lang"),
            "content_type": obj.get("content_type"),
            "encoding": obj.get("encoding"),
            "apparent_encoding": obj.get("apparent_encoding"),
            "description": obj.get("description"),
            "content": obj.get("content"),
            "metadata": obj.get("metadata"),
            "alt_content": obj.get("alt_content"),
            "content_hash": obj.get("content_hash"),
            "author": obj.get("author"),
            "channel_id": obj.get("channel_id"),
            "channel_url": obj.get("channel_url"),
            "channel_title": obj.get("channel_title"),
            "duration": obj.get("duration"),
            "keywords": obj.get("keywords"),
            "doc_type": obj.get("doc_type"),
            "credits": obj.get("credits")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.tracking_sources_response import TrackingSourcesResponse

class TestTrackingSourcesResponse(unittest.TestCase):
    """TrackingSourcesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TrackingSourcesResponse:
        """Test TrackingSourcesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TrackingSourcesResponse`
        """
        model = TrackingSourcesResponse()
        if include_optional:
            return TrackingSourcesResponse(
                sources = [
                    flowhunt.models.tracking_source_response.TrackingSourceResponse(
                        customer_id = '', 
                        link_id = '', 
                        source_type = 'ga', 
                        click_id = '', 
                        click_id_name = 'gclid', 
                        utm_source = '', 
                        utm_medium = '', 
                        utm_campaign = '', 
                        utm_term = '', 
                        utm_content = '', 
                        utm_channel = '', 
                        ga = '', 
                        url = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        valid_until = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        event_data = [
                            flowhunt.models.tracking_event_data.TrackingEventData(
                                key = '', 
                                value_text = '', 
                                value_number = 1.337, 
                                value_boolean = True, 
                                value_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], )
                    ]
            )
        else:
            return TrackingSourcesResponse(
                sources = [
                    flowhunt.models.tracking_source_response.TrackingSourceResponse(
                        customer_id = '', 
                        link_id = '', 
                        source_type = 'ga', 
                        click_id = '', 
                        click_id_name = 'gclid', 
                        utm_source = '', 
                        utm_medium = '', 
                        utm_campaign = '', 
                        utm_term = '', 
                        utm_content = '', 
                        utm_channel = '', 
                        ga = '', 
                        url = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        valid_until = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        event_data = [
                            flowhunt.models.tracking_event_data.TrackingEventData(
                                key = '', 
                                value_text = '', 
                                value_number = 1.337, 
                                value_boolean = True, 
                                value_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], )
                    ],
        )
        """

    def testTrackingSourcesResponse(self):
        """Test TrackingSourcesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.google_ads_campaign_response import GoogleAdsCampaignResponse

class TestGoogleAdsCampaignResponse(unittest.TestCase):
    """GoogleAdsCampaignResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleAdsCampaignResponse:
        """Test GoogleAdsCampaignResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleAdsCampaignResponse`
        """
        model = GoogleAdsCampaignResponse()
        if include_optional:
            return GoogleAdsCampaignResponse(
                workspace_id = '',
                customer_id = '',
                campaign_id = '',
                campaign_name = '',
                campaign_status = 0,
                language_code = '',
                country = '',
                last_update = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                action_type = 'I'
            )
        else:
            return GoogleAdsCampaignResponse(
                workspace_id = '',
                customer_id = '',
                campaign_id = '',
                campaign_name = '',
                campaign_status = 0,
                action_type = 'I',
        )
        """

    def testGoogleAdsCampaignResponse(self):
        """Test GoogleAdsCampaignResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.word_press_api import WordPressApi


class TestWordPressApi(unittest.TestCase):
    """WordPressApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WordPressApi()

    def tearDown(self) -> None:
        pass

    def test_get_wordpress_post_categories(self) -> None:
        """Test case for get_wordpress_post_categories

        Get Wordpress Post Categories
        """
        pass

    def test_get_wordpress_post_tags(self) -> None:
        """Test case for get_wordpress_post_tags

        Get Wordpress Post Tags
        """
        pass

    def test_get_wordpress_sites(self) -> None:
        """Test case for get_wordpress_sites

        Get Wordpress Sites
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.google_ads_match_type import GoogleAdsMatchType
from typing import Optional, Set
from typing_extensions import Self

class GoogleAdsKeywordAddRequest(BaseModel):
    """
    GoogleAdsKeywordAddRequest
    """ # noqa: E501
    customer_id: StrictStr = Field(description="Customer id")
    campaign_id: StrictStr = Field(description="Campaign id")
    group_id: StrictStr = Field(description="Group id")
    keywords: List[StrictStr] = Field(description="List of keywords to add")
    is_negative: Optional[StrictBool] = Field(default=False, description="Is negative keyword")
    match_type: GoogleAdsMatchType = Field(description="Match type")
    __properties: ClassVar[List[str]] = ["customer_id", "campaign_id", "group_id", "keywords", "is_negative", "match_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GoogleAdsKeywordAddRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GoogleAdsKeywordAddRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "customer_id": obj.get("customer_id"),
            "campaign_id": obj.get("campaign_id"),
            "group_id": obj.get("group_id"),
            "keywords": obj.get("keywords"),
            "is_negative": obj.get("is_negative") if obj.get("is_negative") is not None else False,
            "match_type": obj.get("match_type")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.serp_search_request import SerpSearchRequest

class TestSerpSearchRequest(unittest.TestCase):
    """SerpSearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SerpSearchRequest:
        """Test SerpSearchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SerpSearchRequest`
        """
        model = SerpSearchRequest()
        if include_optional:
            return SerpSearchRequest(
                post_back_url = '',
                query = 'liveagent help desk software',
                country = '',
                location = '',
                language = '',
                count_urls = 56
            )
        else:
            return SerpSearchRequest(
                query = 'liveagent help desk software',
        )
        """

    def testSerpSearchRequest(self):
        """Test SerpSearchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.prompts_api import PromptsApi


class TestPromptsApi(unittest.TestCase):
    """PromptsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PromptsApi()

    def tearDown(self) -> None:
        pass

    def test_create_prompt(self) -> None:
        """Test case for create_prompt

        Create Prompt
        """
        pass

    def test_create_prompt_category(self) -> None:
        """Test case for create_prompt_category

        Create Prompt Category
        """
        pass

    def test_delete_prompt(self) -> None:
        """Test case for delete_prompt

        Delete Prompt
        """
        pass

    def test_delete_prompt_category(self) -> None:
        """Test case for delete_prompt_category

        Delete Prompt Category
        """
        pass

    def test_search_prompt_categories(self) -> None:
        """Test case for search_prompt_categories

        Search Prompt Categories
        """
        pass

    def test_search_prompts(self) -> None:
        """Test case for search_prompts

        Search Prompts
        """
        pass

    def test_update_prompt(self) -> None:
        """Test case for update_prompt

        Update Prompt
        """
        pass

    def test_update_prompt_category(self) -> None:
        """Test case for update_prompt_category

        Update Prompt Category
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.workspace_sso_create_request import WorkspaceSSOCreateRequest

class TestWorkspaceSSOCreateRequest(unittest.TestCase):
    """WorkspaceSSOCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkspaceSSOCreateRequest:
        """Test WorkspaceSSOCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorkspaceSSOCreateRequest`
        """
        model = WorkspaceSSOCreateRequest()
        if include_optional:
            return WorkspaceSSOCreateRequest(
                provider = '',
                enabled = True,
                idp_sso_url = '',
                jit_provisioning_enabled = True,
                email_attribute = '',
                name_id_format = '',
                first_name_attribute = '',
                last_name_attribute = '',
                role_attribute = '',
                login_method = 'f',
                idp_metadata_xml = ''
            )
        else:
            return WorkspaceSSOCreateRequest(
                provider = '',
        )
        """

    def testWorkspaceSSOCreateRequest(self):
        """Test WorkspaceSSOCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.web_auth_api import WebAuthApi


class TestWebAuthApi(unittest.TestCase):
    """WebAuthApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WebAuthApi()

    def tearDown(self) -> None:
        pass

    def test_activate_account(self) -> None:
        """Test case for activate_account

        Activate Account
        """
        pass

    def test_get_user(self) -> None:
        """Test case for get_user

        Get User
        """
        pass

    def test_password_recovery_page(self) -> None:
        """Test case for password_recovery_page

        Password Recovery Page
        """
        pass

    def test_password_recovery_submit(self) -> None:
        """Test case for password_recovery_submit

        Password Recovery Submit
        """
        pass

    def test_register_page(self) -> None:
        """Test case for register_page

        Register Page
        """
        pass

    def test_register_submit(self) -> None:
        """Test case for register_submit

        Register Submit
        """
        pass

    def test_reset_password_page(self) -> None:
        """Test case for reset_password_page

        Reset Password Page
        """
        pass

    def test_reset_password_submit(self) -> None:
        """Test case for reset_password_submit

        Reset Password Submit
        """
        pass

    def test_sso_login_page(self) -> None:
        """Test case for sso_login_page

        Sso Login Page
        """
        pass

    def test_sso_login_submit(self) -> None:
        """Test case for sso_login_submit

        Sso Login Submit
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from flowhunt.models.pointer_type import PointerType
from flowhunt.models.vector_document_type import VectorDocumentType
from typing import Optional, Set
from typing_extensions import Self

class QuerySimilarityTaskRequest(BaseModel):
    """
    QuerySimilarityTaskRequest
    """ # noqa: E501
    post_back_url: Optional[StrictStr] = None
    document_type: Optional[VectorDocumentType] = None
    pointer_type: Optional[PointerType] = None
    schema_type: Optional[StrictStr] = None
    limit: Optional[StrictInt] = None
    score_trheshold: Optional[Union[StrictFloat, StrictInt]] = None
    with_vectors: Optional[StrictBool] = None
    pointer_position_from: Optional[StrictInt] = None
    pointer_position_to: Optional[StrictInt] = None
    vector_id_from: Optional[StrictInt] = None
    vector_id_to: Optional[StrictInt] = None
    filter_url: Optional[StrictStr] = None
    filter_domains: Optional[List[StrictStr]] = None
    query: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["post_back_url", "document_type", "pointer_type", "schema_type", "limit", "score_trheshold", "with_vectors", "pointer_position_from", "pointer_position_to", "vector_id_from", "vector_id_to", "filter_url", "filter_domains", "query"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of QuerySimilarityTaskRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if post_back_url (nullable) is None
        # and model_fields_set contains the field
        if self.post_back_url is None and "post_back_url" in self.model_fields_set:
            _dict['post_back_url'] = None

        # set to None if document_type (nullable) is None
        # and model_fields_set contains the field
        if self.document_type is None and "document_type" in self.model_fields_set:
            _dict['document_type'] = None

        # set to None if pointer_type (nullable) is None
        # and model_fields_set contains the field
        if self.pointer_type is None and "pointer_type" in self.model_fields_set:
            _dict['pointer_type'] = None

        # set to None if schema_type (nullable) is None
        # and model_fields_set contains the field
        if self.schema_type is None and "schema_type" in self.model_fields_set:
            _dict['schema_type'] = None

        # set to None if limit (nullable) is None
        # and model_fields_set contains the field
        if self.limit is None and "limit" in self.model_fields_set:
            _dict['limit'] = None

        # set to None if score_trheshold (nullable) is None
        # and model_fields_set contains the field
        if self.score_trheshold is None and "score_trheshold" in self.model_fields_set:
            _dict['score_trheshold'] = None

        # set to None if with_vectors (nullable) is None
        # and model_fields_set contains the field
        if self.with_vectors is None and "with_vectors" in self.model_fields_set:
            _dict['with_vectors'] = None

        # set to None if pointer_position_from (nullable) is None
        # and model_fields_set contains the field
        if self.pointer_position_from is None and "pointer_position_from" in self.model_fields_set:
            _dict['pointer_position_from'] = None

        # set to None if pointer_position_to (nullable) is None
        # and model_fields_set contains the field
        if self.pointer_position_to is None and "pointer_position_to" in self.model_fields_set:
            _dict['pointer_position_to'] = None

        # set to None if vector_id_from (nullable) is None
        # and model_fields_set contains the field
        if self.vector_id_from is None and "vector_id_from" in self.model_fields_set:
            _dict['vector_id_from'] = None

        # set to None if vector_id_to (nullable) is None
        # and model_fields_set contains the field
        if self.vector_id_to is None and "vector_id_to" in self.model_fields_set:
            _dict['vector_id_to'] = None

        # set to None if filter_url (nullable) is None
        # and model_fields_set contains the field
        if self.filter_url is None and "filter_url" in self.model_fields_set:
            _dict['filter_url'] = None

        # set to None if filter_domains (nullable) is None
        # and model_fields_set contains the field
        if self.filter_domains is None and "filter_domains" in self.model_fields_set:
            _dict['filter_domains'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of QuerySimilarityTaskRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "post_back_url": obj.get("post_back_url"),
            "document_type": obj.get("document_type"),
            "pointer_type": obj.get("pointer_type"),
            "schema_type": obj.get("schema_type"),
            "limit": obj.get("limit"),
            "score_trheshold": obj.get("score_trheshold"),
            "with_vectors": obj.get("with_vectors"),
            "pointer_position_from": obj.get("pointer_position_from"),
            "pointer_position_to": obj.get("pointer_position_to"),
            "vector_id_from": obj.get("vector_id_from"),
            "vector_id_to": obj.get("vector_id_to"),
            "filter_url": obj.get("filter_url"),
            "filter_domains": obj.get("filter_domains"),
            "query": obj.get("query")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.log_response import LogResponse

class TestLogResponse(unittest.TestCase):
    """LogResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LogResponse:
        """Test LogResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LogResponse`
        """
        model = LogResponse()
        if include_optional:
            return LogResponse(
                log_id = '',
                log_type = 'S',
                category_id = '',
                log_level = 'I',
                message = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                metadata = {
                    'key' : null
                    }
            )
        else:
            return LogResponse(
                log_id = '',
                log_type = 'S',
                log_level = 'I',
                message = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testLogResponse(self):
        """Test LogResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.inference_history_search_request import InferenceHistorySearchRequest

class TestInferenceHistorySearchRequest(unittest.TestCase):
    """InferenceHistorySearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InferenceHistorySearchRequest:
        """Test InferenceHistorySearchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InferenceHistorySearchRequest`
        """
        model = InferenceHistorySearchRequest()
        if include_optional:
            return InferenceHistorySearchRequest(
                from_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                to_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                limit = 56,
                search_after = [
                    null
                    ],
                base_model = 'flux-dev',
                style = '',
                effect = '',
                aspect_ratio = '1:1'
            )
        else:
            return InferenceHistorySearchRequest(
        )
        """

    def testInferenceHistorySearchRequest(self):
        """Test InferenceHistorySearchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.document_similarity_request import DocumentSimilarityRequest

class TestDocumentSimilarityRequest(unittest.TestCase):
    """DocumentSimilarityRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DocumentSimilarityRequest:
        """Test DocumentSimilarityRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DocumentSimilarityRequest`
        """
        model = DocumentSimilarityRequest()
        if include_optional:
            return DocumentSimilarityRequest(
                document_type = 'U',
                pointer_type = 'C',
                schema_type = '',
                limit = 56,
                score_trheshold = 1.337,
                with_vectors = True,
                pointer_position_from = 56,
                pointer_position_to = 56,
                vector_id_from = 56,
                vector_id_to = 56,
                filter_url = '',
                filter_domains = [
                    ''
                    ],
                document_id = '',
                faq_id = '',
                url_id = '',
                url = ''
            )
        else:
            return DocumentSimilarityRequest(
        )
        """

    def testDocumentSimilarityRequest(self):
        """Test DocumentSimilarityRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.feature_response import FeatureResponse
from flowhunt.models.subscription_plan import SubscriptionPlan
from typing import Optional, Set
from typing_extensions import Self

class PlanListItemResponse(BaseModel):
    """
    PlanListItemResponse
    """ # noqa: E501
    product_id: StrictStr
    price_id: StrictStr
    currency: StrictStr
    amount_monthly: StrictInt
    amount_yearly: Optional[StrictInt] = None
    recurring: StrictBool
    name: StrictStr
    description: StrictStr
    popular: StrictBool
    monthly_credits: StrictInt
    features: List[FeatureResponse]
    subscription_plan: Optional[SubscriptionPlan]
    self_hosted: Optional[StrictBool] = None
    addon: Optional[StrictBool] = None
    addon_type: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["product_id", "price_id", "currency", "amount_monthly", "amount_yearly", "recurring", "name", "description", "popular", "monthly_credits", "features", "subscription_plan", "self_hosted", "addon", "addon_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PlanListItemResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in features (list)
        _items = []
        if self.features:
            for _item_features in self.features:
                if _item_features:
                    _items.append(_item_features.to_dict())
            _dict['features'] = _items
        # set to None if amount_yearly (nullable) is None
        # and model_fields_set contains the field
        if self.amount_yearly is None and "amount_yearly" in self.model_fields_set:
            _dict['amount_yearly'] = None

        # set to None if subscription_plan (nullable) is None
        # and model_fields_set contains the field
        if self.subscription_plan is None and "subscription_plan" in self.model_fields_set:
            _dict['subscription_plan'] = None

        # set to None if self_hosted (nullable) is None
        # and model_fields_set contains the field
        if self.self_hosted is None and "self_hosted" in self.model_fields_set:
            _dict['self_hosted'] = None

        # set to None if addon (nullable) is None
        # and model_fields_set contains the field
        if self.addon is None and "addon" in self.model_fields_set:
            _dict['addon'] = None

        # set to None if addon_type (nullable) is None
        # and model_fields_set contains the field
        if self.addon_type is None and "addon_type" in self.model_fields_set:
            _dict['addon_type'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PlanListItemResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "product_id": obj.get("product_id"),
            "price_id": obj.get("price_id"),
            "currency": obj.get("currency"),
            "amount_monthly": obj.get("amount_monthly"),
            "amount_yearly": obj.get("amount_yearly"),
            "recurring": obj.get("recurring"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "popular": obj.get("popular"),
            "monthly_credits": obj.get("monthly_credits"),
            "features": [FeatureResponse.from_dict(_item) for _item in obj["features"]] if obj.get("features") is not None else None,
            "subscription_plan": obj.get("subscription_plan"),
            "self_hosted": obj.get("self_hosted"),
            "addon": obj.get("addon"),
            "addon_type": obj.get("addon_type")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.flow_sessions_api import FlowSessionsApi


class TestFlowSessionsApi(unittest.TestCase):
    """FlowSessionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlowSessionsApi()

    def tearDown(self) -> None:
        pass

    def test_delete_chatbot_session_view(self) -> None:
        """Test case for delete_chatbot_session_view

        Delete Chatbot Session View
        """
        pass

    def test_get_chatbot_session_view(self) -> None:
        """Test case for get_chatbot_session_view

        Get Chatbot Session View
        """
        pass

    def test_search_chatbot_sessions_view(self) -> None:
        """Test case for search_chatbot_sessions_view

        Search Chatbot Sessions View
        """
        pass

    def test_update_chatbot_session_view(self) -> None:
        """Test case for update_chatbot_session_view

        Update Chatbot Session View
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.integration_response import IntegrationResponse

class TestIntegrationResponse(unittest.TestCase):
    """IntegrationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IntegrationResponse:
        """Test IntegrationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IntegrationResponse`
        """
        model = IntegrationResponse()
        if include_optional:
            return IntegrationResponse(
                slug = 'api_integration',
                name = 'API Integration',
                description = 'API Integration',
                integrated_instance_cnt = 1,
                categories = [
                    'dev_tools'
                    ],
                alpha = True,
                beta = True,
                public_flow_id = ''
            )
        else:
            return IntegrationResponse(
                slug = 'api_integration',
                name = 'API Integration',
                description = 'API Integration',
                integrated_instance_cnt = 1,
                categories = [
                    'dev_tools'
                    ],
        )
        """

    def testIntegrationResponse(self):
        """Test IntegrationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.saml_login_method import SamlLoginMethod
from typing import Optional, Set
from typing_extensions import Self

class WorkspaceSSOUpdateRequest(BaseModel):
    """
    Request DTO for updating workspace SSO settings.
    """ # noqa: E501
    enabled: Optional[StrictBool] = Field(default=True, description="Whether SSO is enabled")
    idp_sso_url: Optional[StrictStr] = None
    idp_entity_id: Optional[StrictStr] = None
    idp_x509_cert: Optional[StrictStr] = None
    jit_provisioning_enabled: Optional[StrictBool] = Field(default=False, description="Enable Just-In-Time user provisioning")
    email_attribute: Optional[StrictStr] = None
    name_id_format: Optional[StrictStr] = None
    first_name_attribute: Optional[StrictStr] = None
    last_name_attribute: Optional[StrictStr] = None
    role_attribute: Optional[StrictStr] = None
    login_method: Optional[SamlLoginMethod] = None
    idp_metadata_xml: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["enabled", "idp_sso_url", "idp_entity_id", "idp_x509_cert", "jit_provisioning_enabled", "email_attribute", "name_id_format", "first_name_attribute", "last_name_attribute", "role_attribute", "login_method", "idp_metadata_xml"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WorkspaceSSOUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if idp_sso_url (nullable) is None
        # and model_fields_set contains the field
        if self.idp_sso_url is None and "idp_sso_url" in self.model_fields_set:
            _dict['idp_sso_url'] = None

        # set to None if idp_entity_id (nullable) is None
        # and model_fields_set contains the field
        if self.idp_entity_id is None and "idp_entity_id" in self.model_fields_set:
            _dict['idp_entity_id'] = None

        # set to None if idp_x509_cert (nullable) is None
        # and model_fields_set contains the field
        if self.idp_x509_cert is None and "idp_x509_cert" in self.model_fields_set:
            _dict['idp_x509_cert'] = None

        # set to None if email_attribute (nullable) is None
        # and model_fields_set contains the field
        if self.email_attribute is None and "email_attribute" in self.model_fields_set:
            _dict['email_attribute'] = None

        # set to None if name_id_format (nullable) is None
        # and model_fields_set contains the field
        if self.name_id_format is None and "name_id_format" in self.model_fields_set:
            _dict['name_id_format'] = None

        # set to None if first_name_attribute (nullable) is None
        # and model_fields_set contains the field
        if self.first_name_attribute is None and "first_name_attribute" in self.model_fields_set:
            _dict['first_name_attribute'] = None

        # set to None if last_name_attribute (nullable) is None
        # and model_fields_set contains the field
        if self.last_name_attribute is None and "last_name_attribute" in self.model_fields_set:
            _dict['last_name_attribute'] = None

        # set to None if role_attribute (nullable) is None
        # and model_fields_set contains the field
        if self.role_attribute is None and "role_attribute" in self.model_fields_set:
            _dict['role_attribute'] = None

        # set to None if login_method (nullable) is None
        # and model_fields_set contains the field
        if self.login_method is None and "login_method" in self.model_fields_set:
            _dict['login_method'] = None

        # set to None if idp_metadata_xml (nullable) is None
        # and model_fields_set contains the field
        if self.idp_metadata_xml is None and "idp_metadata_xml" in self.model_fields_set:
            _dict['idp_metadata_xml'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WorkspaceSSOUpdateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else True,
            "idp_sso_url": obj.get("idp_sso_url"),
            "idp_entity_id": obj.get("idp_entity_id"),
            "idp_x509_cert": obj.get("idp_x509_cert"),
            "jit_provisioning_enabled": obj.get("jit_provisioning_enabled") if obj.get("jit_provisioning_enabled") is not None else False,
            "email_attribute": obj.get("email_attribute"),
            "name_id_format": obj.get("name_id_format"),
            "first_name_attribute": obj.get("first_name_attribute"),
            "last_name_attribute": obj.get("last_name_attribute"),
            "role_attribute": obj.get("role_attribute"),
            "login_method": obj.get("login_method"),
            "idp_metadata_xml": obj.get("idp_metadata_xml")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.semantic_search_api import SemanticSearchApi


class TestSemanticSearchApi(unittest.TestCase):
    """SemanticSearchApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SemanticSearchApi()

    def tearDown(self) -> None:
        pass

    def test_get_similar_docs_by_doc_id(self) -> None:
        """Test case for get_similar_docs_by_doc_id

        Get Similar Docs By Doc Id
        """
        pass

    def test_get_similar_docs_by_query(self) -> None:
        """Test case for get_similar_docs_by_query

        Get Similar Docs By Query
        """
        pass

    def test_schedule_similar_docs_by_doc_id(self) -> None:
        """Test case for schedule_similar_docs_by_doc_id

        Schedule Similar Docs By Doc Id
        """
        pass

    def test_schedule_similar_docs_by_query(self) -> None:
        """Test case for schedule_similar_docs_by_query

        Schedule Similar Docs By Query
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.chatbot_status import ChatbotStatus
from typing import Optional, Set
from typing_extensions import Self

class ChatbotResponse(BaseModel):
    """
    ChatbotResponse
    """ # noqa: E501
    workspace_id: StrictStr = Field(description="Workspace id")
    chatbot_id: StrictStr = Field(description="Chatbot id")
    title: StrictStr = Field(description="Tenant name")
    description: Optional[StrictStr] = None
    flow_id: StrictStr = Field(description="Flow ID")
    status: Optional[ChatbotStatus]
    url_suffix: Optional[StrictStr] = None
    theme: Optional[StrictStr] = None
    max_window_size: Optional[StrictStr] = None
    msg_rpm: Optional[StrictInt] = None
    msg_ip_rpm: Optional[StrictInt] = None
    chatbot_description: Optional[StrictStr] = None
    show_chatbot_header: Optional[StrictBool] = None
    chat_bubble_bg_color: Optional[StrictStr] = None
    chat_bubble_icon_color: Optional[StrictStr] = None
    chat_bubble_img_url: Optional[StrictStr] = None
    chatbot_theme: Optional[StrictStr] = None
    chatbot_position: Optional[StrictStr] = None
    message_placeholder: Optional[StrictStr] = None
    chatbot_header_text: Optional[StrictStr] = None
    chatbot_header_logo_url: Optional[StrictStr] = None
    assistant_avatar_image_url: Optional[StrictStr] = None
    remove_branding: Optional[StrictBool] = None
    chatbot_style: Optional[StrictStr] = None
    session_message_history: Optional[StrictBool] = None
    chatbot_bubble_size: Optional[StrictInt] = None
    message_header_logo_url: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["workspace_id", "chatbot_id", "title", "description", "flow_id", "status", "url_suffix", "theme", "max_window_size", "msg_rpm", "msg_ip_rpm", "chatbot_description", "show_chatbot_header", "chat_bubble_bg_color", "chat_bubble_icon_color", "chat_bubble_img_url", "chatbot_theme", "chatbot_position", "message_placeholder", "chatbot_header_text", "chatbot_header_logo_url", "assistant_avatar_image_url", "remove_branding", "chatbot_style", "session_message_history", "chatbot_bubble_size", "message_header_logo_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatbotResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if url_suffix (nullable) is None
        # and model_fields_set contains the field
        if self.url_suffix is None and "url_suffix" in self.model_fields_set:
            _dict['url_suffix'] = None

        # set to None if theme (nullable) is None
        # and model_fields_set contains the field
        if self.theme is None and "theme" in self.model_fields_set:
            _dict['theme'] = None

        # set to None if max_window_size (nullable) is None
        # and model_fields_set contains the field
        if self.max_window_size is None and "max_window_size" in self.model_fields_set:
            _dict['max_window_size'] = None

        # set to None if msg_rpm (nullable) is None
        # and model_fields_set contains the field
        if self.msg_rpm is None and "msg_rpm" in self.model_fields_set:
            _dict['msg_rpm'] = None

        # set to None if msg_ip_rpm (nullable) is None
        # and model_fields_set contains the field
        if self.msg_ip_rpm is None and "msg_ip_rpm" in self.model_fields_set:
            _dict['msg_ip_rpm'] = None

        # set to None if chatbot_description (nullable) is None
        # and model_fields_set contains the field
        if self.chatbot_description is None and "chatbot_description" in self.model_fields_set:
            _dict['chatbot_description'] = None

        # set to None if show_chatbot_header (nullable) is None
        # and model_fields_set contains the field
        if self.show_chatbot_header is None and "show_chatbot_header" in self.model_fields_set:
            _dict['show_chatbot_header'] = None

        # set to None if chat_bubble_bg_color (nullable) is None
        # and model_fields_set contains the field
        if self.chat_bubble_bg_color is None and "chat_bubble_bg_color" in self.model_fields_set:
            _dict['chat_bubble_bg_color'] = None

        # set to None if chat_bubble_icon_color (nullable) is None
        # and model_fields_set contains the field
        if self.chat_bubble_icon_color is None and "chat_bubble_icon_color" in self.model_fields_set:
            _dict['chat_bubble_icon_color'] = None

        # set to None if chat_bubble_img_url (nullable) is None
        # and model_fields_set contains the field
        if self.chat_bubble_img_url is None and "chat_bubble_img_url" in self.model_fields_set:
            _dict['chat_bubble_img_url'] = None

        # set to None if chatbot_theme (nullable) is None
        # and model_fields_set contains the field
        if self.chatbot_theme is None and "chatbot_theme" in self.model_fields_set:
            _dict['chatbot_theme'] = None

        # set to None if chatbot_position (nullable) is None
        # and model_fields_set contains the field
        if self.chatbot_position is None and "chatbot_position" in self.model_fields_set:
            _dict['chatbot_position'] = None

        # set to None if message_placeholder (nullable) is None
        # and model_fields_set contains the field
        if self.message_placeholder is None and "message_placeholder" in self.model_fields_set:
            _dict['message_placeholder'] = None

        # set to None if chatbot_header_text (nullable) is None
        # and model_fields_set contains the field
        if self.chatbot_header_text is None and "chatbot_header_text" in self.model_fields_set:
            _dict['chatbot_header_text'] = None

        # set to None if chatbot_header_logo_url (nullable) is None
        # and model_fields_set contains the field
        if self.chatbot_header_logo_url is None and "chatbot_header_logo_url" in self.model_fields_set:
            _dict['chatbot_header_logo_url'] = None

        # set to None if assistant_avatar_image_url (nullable) is None
        # and model_fields_set contains the field
        if self.assistant_avatar_image_url is None and "assistant_avatar_image_url" in self.model_fields_set:
            _dict['assistant_avatar_image_url'] = None

        # set to None if remove_branding (nullable) is None
        # and model_fields_set contains the field
        if self.remove_branding is None and "remove_branding" in self.model_fields_set:
            _dict['remove_branding'] = None

        # set to None if chatbot_style (nullable) is None
        # and model_fields_set contains the field
        if self.chatbot_style is None and "chatbot_style" in self.model_fields_set:
            _dict['chatbot_style'] = None

        # set to None if session_message_history (nullable) is None
        # and model_fields_set contains the field
        if self.session_message_history is None and "session_message_history" in self.model_fields_set:
            _dict['session_message_history'] = None

        # set to None if chatbot_bubble_size (nullable) is None
        # and model_fields_set contains the field
        if self.chatbot_bubble_size is None and "chatbot_bubble_size" in self.model_fields_set:
            _dict['chatbot_bubble_size'] = None

        # set to None if message_header_logo_url (nullable) is None
        # and model_fields_set contains the field
        if self.message_header_logo_url is None and "message_header_logo_url" in self.model_fields_set:
            _dict['message_header_logo_url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatbotResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "workspace_id": obj.get("workspace_id"),
            "chatbot_id": obj.get("chatbot_id"),
            "title": obj.get("title"),
            "description": obj.get("description"),
            "flow_id": obj.get("flow_id"),
            "status": obj.get("status"),
            "url_suffix": obj.get("url_suffix"),
            "theme": obj.get("theme"),
            "max_window_size": obj.get("max_window_size"),
            "msg_rpm": obj.get("msg_rpm"),
            "msg_ip_rpm": obj.get("msg_ip_rpm"),
            "chatbot_description": obj.get("chatbot_description"),
            "show_chatbot_header": obj.get("show_chatbot_header"),
            "chat_bubble_bg_color": obj.get("chat_bubble_bg_color"),
            "chat_bubble_icon_color": obj.get("chat_bubble_icon_color"),
            "chat_bubble_img_url": obj.get("chat_bubble_img_url"),
            "chatbot_theme": obj.get("chatbot_theme"),
            "chatbot_position": obj.get("chatbot_position"),
            "message_placeholder": obj.get("message_placeholder"),
            "chatbot_header_text": obj.get("chatbot_header_text"),
            "chatbot_header_logo_url": obj.get("chatbot_header_logo_url"),
            "assistant_avatar_image_url": obj.get("assistant_avatar_image_url"),
            "remove_branding": obj.get("remove_branding"),
            "chatbot_style": obj.get("chatbot_style"),
            "session_message_history": obj.get("session_message_history"),
            "chatbot_bubble_size": obj.get("chatbot_bubble_size"),
            "message_header_logo_url": obj.get("message_header_logo_url")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "3.14.5"

# Define package exports
__all__ = [
    "ApiKeysApi",
    "BillingApi",
    "ChatbotsApi",
    "CreditsApi",
    "DocumentsApi",
    "FineTuningsApi",
    "FlowAssistantApi",
    "FlowMessagesApi",
    "FlowSessionsApi",
    "FlowWebhooksApi",
    "FlowsApi",
    "GoogleApi",
    "GoogleAdsApi",
    "HealthApi",
    "HubSpotApi",
    "ImagesApi",
    "InstagramApi",
    "IntegrationsApi",
    "LogsApi",
    "MCPServersApi",
    "MediaApi",
    "MicrosoftOutlookApi",
    "OAuthApi",
    "ObservabilityDriverApi",
    "PhotoAIApi",
    "PromptsApi",
    "SERPApi",
    "SchedulesApi",
    "SecretsApi",
    "SemanticSearchApi",
    "ShopifyApi",
    "SlackApi",
    "TagsApi",
    "TrackingApi",
    "WebAuthApi",
    "WordPressApi",
    "WorkspacesApi",
    "WorkspacesSSOApi",
    "WorkspacesSSODomainVerificationApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AllFlowsSearchRequest",
    "ApiKeyCreateRequest",
    "ApiKeyResponse",
    "ApiKeySearchRequest",
    "ApiKeyUpdateRequest",
    "AppUrlInput",
    "AppUrlOutput",
    "AspecRatio",
    "BaseFoundationModel",
    "BoolChar",
    "ChatbotCreateRequest",
    "ChatbotResponse",
    "ChatbotSearchRequest",
    "ChatbotStatus",
    "ChatbotUpdateRequest",
    "CheckoutCreateRequest",
    "CommunityImageGenerationsResponse",
    "Completed",
    "CreditBalanceResponse",
    "CreditDailyTransactionResponse",
    "CreditDailyTransactionSearchRequest",
    "CreditTransactionResponse",
    "CreditTransactionSearchRequest",
    "CustomerDataRequestPayload",
    "CustomerRedactPayload",
    "Data",
    "DocumentCategoryCreateRequest",
    "DocumentCategoryResponse",
    "DocumentCategorySearchRequest",
    "DocumentCategoryUpdateRequest",
    "DocumentContent",
    "DocumentContentResponse",
    "DocumentResponse",
    "DocumentSearchRequest",
    "DocumentSimilarityRequest",
    "DocumentSimilarityTaskRequest",
    "DocumentStatus",
    "DocumentType",
    "DocumentUpdateRequest",
    "DriverSuccessResponse",
    "DriverType",
    "FTStatus",
    "FTType",
    "FaqCreateRequest",
    "FaqResponse",
    "FaqSearchRequest",
    "FaqStatus",
    "FaqType",
    "FaqUpdateRequest",
    "FeatureResponse",
    "FileUploadResponse",
    "FlowAssistantAIModel",
    "FlowAssistantAddComponentMetadata",
    "FlowAssistantAddConnectionMetadata",
    "FlowAssistantApplyRejectChangesRequest",
    "FlowAssistantCreateBlankFlowMetadata",
    "FlowAssistantDeleteComponentMetadata",
    "FlowAssistantDeleteConnectionMetadata",
    "FlowAssistantInvokeRequest",
    "FlowAssistantSessionCreateRequest",
    "FlowAssistantUpdateComponentMetadata",
    "FlowBranch",
    "FlowCategoryCreateRequest",
    "FlowCategoryResponse",
    "FlowCategorySearchRequest",
    "FlowCommitRequest",
    "FlowCommitResponse",
    "FlowConfig",
    "FlowCreate",
    "FlowCronCreateRequest",
    "FlowCronResponse",
    "FlowCronSearchRequest",
    "FlowCronStatus",
    "FlowCronUpdateRequest",
    "FlowDetailResponse",
    "FlowEventActionType",
    "FlowHuntProductSlug",
    "FlowInvokeRequest",
    "FlowResponse",
    "FlowSearchRequest",
    "FlowSessionAttachmentResponse",
    "FlowSessionCreateFromFlowRequest",
    "FlowSessionCreateRequest",
    "FlowSessionEvent",
    "FlowSessionInvocationResponse",
    "FlowSessionInvokeRequest",
    "FlowSessionLoadingMetadata",
    "FlowSessionMessageMetadata",
    "FlowSessionResponse",
    "FlowSessionTaskResponseMetadata",
    "FlowSessionToolCallMetadata",
    "FlowSessionViewResponse",
    "FlowSessionViewSearchRequest",
    "FlowSessionViewUpdateRequest",
    "FlowType",
    "FlowUpdate",
    "FlowVersionHistoryResponse",
    "GeneralMCPSubserverCapabilitiesResponse",
    "GeneralMCPSubserverResponse",
    "GoogleAdsActionType",
    "GoogleAdsAnalyzeKeywordsRequest",
    "GoogleAdsCampaignResponse",
    "GoogleAdsCampaignStatus",
    "GoogleAdsCampaignUpdateRequest",
    "GoogleAdsCampaignsResponse",
    "GoogleAdsCampaignsSearchRequest",
    "GoogleAdsCustomerResponse",
    "GoogleAdsCustomerUpdateRequest",
    "GoogleAdsCustomersResponse",
    "GoogleAdsCustomersSearchRequest",
    "GoogleAdsGroupResponse",
    "GoogleAdsGroupStatus",
    "GoogleAdsGroupUpdateRequest",
    "GoogleAdsGroupsResponse",
    "GoogleAdsGroupsSearchRequest",
    "GoogleAdsKeywordAddRequest",
    "GoogleAdsKeywordRecommendation",
    "GoogleAdsKeywordRemoveRequest",
    "GoogleAdsMatchType",
    "GoogleAdsRecommendation",
    "GoogleAdsRecommendationConfidence",
    "GoogleAdsRecommendationStatus",
    "GoogleAdsRecommendationType",
    "GoogleAdsRecommendationsRequest",
    "GoogleCalendarResponse",
    "GoogleCalendarsResponse",
    "GooglePickerTokenResponse",
    "GoogleSheetResponse",
    "GoogleSheetsResponse",
    "HTTPValidationError",
    "Health",
    "HubSpotActorIdResponse",
    "HubSpotActorsResponse",
    "ImageConvertRequest",
    "ImageFTCreateRequest",
    "ImageFTResponse",
    "ImageFTSearchRequest",
    "ImageFTUpdateRequest",
    "ImageInferenceRequest",
    "ImageInferenceResponse",
    "ImageInferenceResultResponse",
    "ImageInferenceScheduleResponse",
    "ImageInferenceScrollResponse",
    "ImageOptimizeRequest",
    "ImagePromptGenerationRequest",
    "ImagePromptResponse",
    "InferenceFileType",
    "InferenceHistorySearchRequest",
    "InstagramProfileInformationResponse",
    "IntegrationCategory",
    "IntegrationDetailResponse",
    "IntegrationFlowResponse",
    "IntegrationResponse",
    "IntegrationSearchRequest",
    "IntegrationSlug",
    "LangfuseRequest",
    "LogEntryLevel",
    "LogEntryType",
    "LogResponse",
    "LogsSearchRequest",
    "MCPCapabilityBinding",
    "MCPServerCreateRequest",
    "MCPServerResponse",
    "MCPServerSearchRequest",
    "MCPSubServerBinding",
    "MessageType",
    "Metadata",
    "ObservabilityDriverResponse",
    "Pagination",
    "PhotoAIEffectResponse",
    "PhotoAIStyleResponse",
    "PhotoAITemplateResponse",
    "PlanListItemResponse",
    "PlanResponse",
    "PointerType",
    "PromptCategoryCreateRequest",
    "PromptCategoryResponse",
    "PromptCategorySearchRequest",
    "PromptCategoryUpdateRequest",
    "PromptCreateRequest",
    "PromptResponse",
    "PromptSearchRequest",
    "PromptUpdateRequest",
    "QuerySimilarityRequest",
    "QuerySimilarityTaskRequest",
    "Role",
    "SamlLoginMethod",
    "ScheduleCreateRequest",
    "ScheduleFrequency",
    "ScheduleResponse",
    "ScheduleSearchRequest",
    "ScheduleStatus",
    "ScheduleType",
    "ScheduleUpdateRequest",
    "ScheduleUrlDetailResponse",
    "ScheduleUrlResponse",
    "ScheduleUrlSearchRequest",
    "ScreenshotRequest",
    "ScreenshotResponse",
    "SecretCreateRequest",
    "SecretResponse",
    "SecretSearchRequest",
    "SecretUpdateRequest",
    "SerpClusterAddQueryRequest",
    "SerpClusterAddQueryRequests",
    "SerpClusterBestGroupsRequest",
    "SerpClusterGroupIntersectionsRequest",
    "SerpClusterGroupSearchRequest",
    "SerpClusterGroupSubClustersRequest",
    "SerpClusterKeywordIntersectionsRequest",
    "SerpClusterKeywordResponse",
    "SerpGroupIntersection",
    "SerpKeyword",
    "SerpKeywordRelation",
    "SerpQueryRequest",
    "SerpSearchEngineType",
    "SerpSearchRequest",
    "SerpSearchRequests",
    "SerpSubclusterKeywordsResponse",
    "SerpVolumeRequest",
    "ShopRedactPayload",
    "SlackChannelResponse",
    "SlackWorkspaceResponse",
    "SortDirection",
    "SubscriptionPlan",
    "TagCreateRequest",
    "TagResponse",
    "TagSearchRequest",
    "TagUpdateRequest",
    "TaskResponse",
    "TaskStatus",
    "TrackingClickIdNames",
    "TrackingEventCreateRequest",
    "TrackingEventCreateRequests",
    "TrackingEventData",
    "TrackingEventResponse",
    "TrackingEventSearchRequest",
    "TrackingEventsResponse",
    "TrackingLinkCreateRequest",
    "TrackingLinkResponse",
    "TrackingLinkSearchRequest",
    "TrackingLinksCreateRequest",
    "TrackingLinksResponse",
    "TrackingSourceCreateRequest",
    "TrackingSourceResponse",
    "TrackingSourceSearchRequest",
    "TrackingSourceTypes",
    "TrackingSourcesResponse",
    "TransactionType",
    "TranscriptTaskRequest",
    "TriggerResponse",
    "TriggerType",
    "UrlScreenshotResponse",
    "UserDocumentStatus",
    "UserPlanResponse",
    "UserResponse",
    "ValidationError",
    "ValidationErrorLocInner",
    "VectorDocumentResponse",
    "VectorDocumentType",
    "VectorDocumentsTaskResponse",
    "WordPressCategoryResponse",
    "WordPressSiteResponse",
    "WordPressTagsResponse",
    "WorkspaceCreateRequest",
    "WorkspaceResponse",
    "WorkspaceRole",
    "WorkspaceSSOCreateRequest",
    "WorkspaceSSODomainVerificationCreateRequest",
    "WorkspaceSSODomainVerificationResponse",
    "WorkspaceSSOListResponse",
    "WorkspaceSSOResponse",
    "WorkspaceSSOUpdateRequest",
    "WorkspaceSearchRequest",
    "WorkspaceUpdateRequest",
    "WorkspaceUserCreateRequest",
    "WorkspaceUserResponse",
    "WorkspaceUserUpdateRequest",
    "WorkspaceUsersSearchRequest",
    "YoutubeContent",
    "YoutubeTranscriptRequest",
    "YoutubeTranscriptResponse",
]

# import apis into sdk package
from flowhunt.api.api_keys_api import ApiKeysApi as ApiKeysApi
from flowhunt.api.billing_api import BillingApi as BillingApi
from flowhunt.api.chatbots_api import ChatbotsApi as ChatbotsApi
from flowhunt.api.credits_api import CreditsApi as CreditsApi
from flowhunt.api.documents_api import DocumentsApi as DocumentsApi
from flowhunt.api.fine_tunings_api import FineTuningsApi as FineTuningsApi
from flowhunt.api.flow_assistant_api import FlowAssistantApi as FlowAssistantApi
from flowhunt.api.flow_messages_api import FlowMessagesApi as FlowMessagesApi
from flowhunt.api.flow_sessions_api import FlowSessionsApi as FlowSessionsApi
from flowhunt.api.flow_webhooks_api import FlowWebhooksApi as FlowWebhooksApi
from flowhunt.api.flows_api import FlowsApi as FlowsApi
from flowhunt.api.google_api import GoogleApi as GoogleApi
from flowhunt.api.google_ads_api import GoogleAdsApi as GoogleAdsApi
from flowhunt.api.health_api import HealthApi as HealthApi
from flowhunt.api.hub_spot_api import HubSpotApi as HubSpotApi
from flowhunt.api.images_api import ImagesApi as ImagesApi
from flowhunt.api.instagram_api import InstagramApi as InstagramApi
from flowhunt.api.integrations_api import IntegrationsApi as IntegrationsApi
from flowhunt.api.logs_api import LogsApi as LogsApi
from flowhunt.api.mcp_servers_api import MCPServersApi as MCPServersApi
from flowhunt.api.media_api import MediaApi as MediaApi
from flowhunt.api.microsoft_outlook_api import MicrosoftOutlookApi as MicrosoftOutlookApi
from flowhunt.api.o_auth_api import OAuthApi as OAuthApi
from flowhunt.api.observability_driver_api import ObservabilityDriverApi as ObservabilityDriverApi
from flowhunt.api.photo_ai_api import PhotoAIApi as PhotoAIApi
from flowhunt.api.prompts_api import PromptsApi as PromptsApi
from flowhunt.api.serp_api import SERPApi as SERPApi
from flowhunt.api.schedules_api import SchedulesApi as SchedulesApi
from flowhunt.api.secrets_api import SecretsApi as SecretsApi
from flowhunt.api.semantic_search_api import SemanticSearchApi as SemanticSearchApi
from flowhunt.api.shopify_api import ShopifyApi as ShopifyApi
from flowhunt.api.slack_api import SlackApi as SlackApi
from flowhunt.api.tags_api import TagsApi as TagsApi
from flowhunt.api.tracking_api import TrackingApi as TrackingApi
from flowhunt.api.web_auth_api import WebAuthApi as WebAuthApi
from flowhunt.api.word_press_api import WordPressApi as WordPressApi
from flowhunt.api.workspaces_api import WorkspacesApi as WorkspacesApi
from flowhunt.api.workspaces_sso_api import WorkspacesSSOApi as WorkspacesSSOApi
from flowhunt.api.workspaces_sso_domain_verification_api import WorkspacesSSODomainVerificationApi as WorkspacesSSODomainVerificationApi

# import ApiClient
from flowhunt.api_response import ApiResponse as ApiResponse
from flowhunt.api_client import ApiClient as ApiClient
from flowhunt.configuration import Configuration as Configuration
from flowhunt.exceptions import OpenApiException as OpenApiException
from flowhunt.exceptions import ApiTypeError as ApiTypeError
from flowhunt.exceptions import ApiValueError as ApiValueError
from flowhunt.exceptions import ApiKeyError as ApiKeyError
from flowhunt.exceptions import ApiAttributeError as ApiAttributeError
from flowhunt.exceptions import ApiException as ApiException

# import models into sdk package
from flowhunt.models.all_flows_search_request import AllFlowsSearchRequest as AllFlowsSearchRequest
from flowhunt.models.api_key_create_request import ApiKeyCreateRequest as ApiKeyCreateRequest
from flowhunt.models.api_key_response import ApiKeyResponse as ApiKeyResponse
from flowhunt.models.api_key_search_request import ApiKeySearchRequest as ApiKeySearchRequest
from flowhunt.models.api_key_update_request import ApiKeyUpdateRequest as ApiKeyUpdateRequest
from flowhunt.models.app_url_input import AppUrlInput as AppUrlInput
from flowhunt.models.app_url_output import AppUrlOutput as AppUrlOutput
from flowhunt.models.aspec_ratio import AspecRatio as AspecRatio
from flowhunt.models.base_foundation_model import BaseFoundationModel as BaseFoundationModel
from flowhunt.models.bool_char import BoolChar as BoolChar
from flowhunt.models.chatbot_create_request import ChatbotCreateRequest as ChatbotCreateRequest
from flowhunt.models.chatbot_response import ChatbotResponse as ChatbotResponse
from flowhunt.models.chatbot_search_request import ChatbotSearchRequest as ChatbotSearchRequest
from flowhunt.models.chatbot_status import ChatbotStatus as ChatbotStatus
from flowhunt.models.chatbot_update_request import ChatbotUpdateRequest as ChatbotUpdateRequest
from flowhunt.models.checkout_create_request import CheckoutCreateRequest as CheckoutCreateRequest
from flowhunt.models.community_image_generations_response import CommunityImageGenerationsResponse as CommunityImageGenerationsResponse
from flowhunt.models.completed import Completed as Completed
from flowhunt.models.credit_balance_response import CreditBalanceResponse as CreditBalanceResponse
from flowhunt.models.credit_daily_transaction_response import CreditDailyTransactionResponse as CreditDailyTransactionResponse
from flowhunt.models.credit_daily_transaction_search_request import CreditDailyTransactionSearchRequest as CreditDailyTransactionSearchRequest
from flowhunt.models.credit_transaction_response import CreditTransactionResponse as CreditTransactionResponse
from flowhunt.models.credit_transaction_search_request import CreditTransactionSearchRequest as CreditTransactionSearchRequest
from flowhunt.models.customer_data_request_payload import CustomerDataRequestPayload as CustomerDataRequestPayload
from flowhunt.models.customer_redact_payload import CustomerRedactPayload as CustomerRedactPayload
from flowhunt.models.data import Data as Data
from flowhunt.models.document_category_create_request import DocumentCategoryCreateRequest as DocumentCategoryCreateRequest
from flowhunt.models.document_category_response import DocumentCategoryResponse as DocumentCategoryResponse
from flowhunt.models.document_category_search_request import DocumentCategorySearchRequest as DocumentCategorySearchRequest
from flowhunt.models.document_category_update_request import DocumentCategoryUpdateRequest as DocumentCategoryUpdateRequest
from flowhunt.models.document_content import DocumentContent as DocumentContent
from flowhunt.models.document_content_response import DocumentContentResponse as DocumentContentResponse
from flowhunt.models.document_response import DocumentResponse as DocumentResponse
from flowhunt.models.document_search_request import DocumentSearchRequest as DocumentSearchRequest
from flowhunt.models.document_similarity_request import DocumentSimilarityRequest as DocumentSimilarityRequest
from flowhunt.models.document_similarity_task_request import DocumentSimilarityTaskRequest as DocumentSimilarityTaskRequest
from flowhunt.models.document_status import DocumentStatus as DocumentStatus
from flowhunt.models.document_type import DocumentType as DocumentType
from flowhunt.models.document_update_request import DocumentUpdateRequest as DocumentUpdateRequest
from flowhunt.models.driver_success_response import DriverSuccessResponse as DriverSuccessResponse
from flowhunt.models.driver_type import DriverType as DriverType
from flowhunt.models.ft_status import FTStatus as FTStatus
from flowhunt.models.ft_type import FTType as FTType
from flowhunt.models.faq_create_request import FaqCreateRequest as FaqCreateRequest
from flowhunt.models.faq_response import FaqResponse as FaqResponse
from flowhunt.models.faq_search_request import FaqSearchRequest as FaqSearchRequest
from flowhunt.models.faq_status import FaqStatus as FaqStatus
from flowhunt.models.faq_type import FaqType as FaqType
from flowhunt.models.faq_update_request import FaqUpdateRequest as FaqUpdateRequest
from flowhunt.models.feature_response import FeatureResponse as FeatureResponse
from flowhunt.models.file_upload_response import FileUploadResponse as FileUploadResponse
from flowhunt.models.flow_assistant_ai_model import FlowAssistantAIModel as FlowAssistantAIModel
from flowhunt.models.flow_assistant_add_component_metadata import FlowAssistantAddComponentMetadata as FlowAssistantAddComponentMetadata
from flowhunt.models.flow_assistant_add_connection_metadata import FlowAssistantAddConnectionMetadata as FlowAssistantAddConnectionMetadata
from flowhunt.models.flow_assistant_apply_reject_changes_request import FlowAssistantApplyRejectChangesRequest as FlowAssistantApplyRejectChangesRequest
from flowhunt.models.flow_assistant_create_blank_flow_metadata import FlowAssistantCreateBlankFlowMetadata as FlowAssistantCreateBlankFlowMetadata
from flowhunt.models.flow_assistant_delete_component_metadata import FlowAssistantDeleteComponentMetadata as FlowAssistantDeleteComponentMetadata
from flowhunt.models.flow_assistant_delete_connection_metadata import FlowAssistantDeleteConnectionMetadata as FlowAssistantDeleteConnectionMetadata
from flowhunt.models.flow_assistant_invoke_request import FlowAssistantInvokeRequest as FlowAssistantInvokeRequest
from flowhunt.models.flow_assistant_session_create_request import FlowAssistantSessionCreateRequest as FlowAssistantSessionCreateRequest
from flowhunt.models.flow_assistant_update_component_metadata import FlowAssistantUpdateComponentMetadata as FlowAssistantUpdateComponentMetadata
from flowhunt.models.flow_branch import FlowBranch as FlowBranch
from flowhunt.models.flow_category_create_request import FlowCategoryCreateRequest as FlowCategoryCreateRequest
from flowhunt.models.flow_category_response import FlowCategoryResponse as FlowCategoryResponse
from flowhunt.models.flow_category_search_request import FlowCategorySearchRequest as FlowCategorySearchRequest
from flowhunt.models.flow_commit_request import FlowCommitRequest as FlowCommitRequest
from flowhunt.models.flow_commit_response import FlowCommitResponse as FlowCommitResponse
from flowhunt.models.flow_config import FlowConfig as FlowConfig
from flowhunt.models.flow_create import FlowCreate as FlowCreate
from flowhunt.models.flow_cron_create_request import FlowCronCreateRequest as FlowCronCreateRequest
from flowhunt.models.flow_cron_response import FlowCronResponse as FlowCronResponse
from flowhunt.models.flow_cron_search_request import FlowCronSearchRequest as FlowCronSearchRequest
from flowhunt.models.flow_cron_status import FlowCronStatus as FlowCronStatus
from flowhunt.models.flow_cron_update_request import FlowCronUpdateRequest as FlowCronUpdateRequest
from flowhunt.models.flow_detail_response import FlowDetailResponse as FlowDetailResponse
from flowhunt.models.flow_event_action_type import FlowEventActionType as FlowEventActionType
from flowhunt.models.flow_hunt_product_slug import FlowHuntProductSlug as FlowHuntProductSlug
from flowhunt.models.flow_invoke_request import FlowInvokeRequest as FlowInvokeRequest
from flowhunt.models.flow_response import FlowResponse as FlowResponse
from flowhunt.models.flow_search_request import FlowSearchRequest as FlowSearchRequest
from flowhunt.models.flow_session_attachment_response import FlowSessionAttachmentResponse as FlowSessionAttachmentResponse
from flowhunt.models.flow_session_create_from_flow_request import FlowSessionCreateFromFlowRequest as FlowSessionCreateFromFlowRequest
from flowhunt.models.flow_session_create_request import FlowSessionCreateRequest as FlowSessionCreateRequest
from flowhunt.models.flow_session_event import FlowSessionEvent as FlowSessionEvent
from flowhunt.models.flow_session_invocation_response import FlowSessionInvocationResponse as FlowSessionInvocationResponse
from flowhunt.models.flow_session_invoke_request import FlowSessionInvokeRequest as FlowSessionInvokeRequest
from flowhunt.models.flow_session_loading_metadata import FlowSessionLoadingMetadata as FlowSessionLoadingMetadata
from flowhunt.models.flow_session_message_metadata import FlowSessionMessageMetadata as FlowSessionMessageMetadata
from flowhunt.models.flow_session_response import FlowSessionResponse as FlowSessionResponse
from flowhunt.models.flow_session_task_response_metadata import FlowSessionTaskResponseMetadata as FlowSessionTaskResponseMetadata
from flowhunt.models.flow_session_tool_call_metadata import FlowSessionToolCallMetadata as FlowSessionToolCallMetadata
from flowhunt.models.flow_session_view_response import FlowSessionViewResponse as FlowSessionViewResponse
from flowhunt.models.flow_session_view_search_request import FlowSessionViewSearchRequest as FlowSessionViewSearchRequest
from flowhunt.models.flow_session_view_update_request import FlowSessionViewUpdateRequest as FlowSessionViewUpdateRequest
from flowhunt.models.flow_type import FlowType as FlowType
from flowhunt.models.flow_update import FlowUpdate as FlowUpdate
from flowhunt.models.flow_version_history_response import FlowVersionHistoryResponse as FlowVersionHistoryResponse
from flowhunt.models.general_mcp_subserver_capabilities_response import GeneralMCPSubserverCapabilitiesResponse as GeneralMCPSubserverCapabilitiesResponse
from flowhunt.models.general_mcp_subserver_response import GeneralMCPSubserverResponse as GeneralMCPSubserverResponse
from flowhunt.models.google_ads_action_type import GoogleAdsActionType as GoogleAdsActionType
from flowhunt.models.google_ads_analyze_keywords_request import GoogleAdsAnalyzeKeywordsRequest as GoogleAdsAnalyzeKeywordsRequest
from flowhunt.models.google_ads_campaign_response import GoogleAdsCampaignResponse as GoogleAdsCampaignResponse
from flowhunt.models.google_ads_campaign_status import GoogleAdsCampaignStatus as GoogleAdsCampaignStatus
from flowhunt.models.google_ads_campaign_update_request import GoogleAdsCampaignUpdateRequest as GoogleAdsCampaignUpdateRequest
from flowhunt.models.google_ads_campaigns_response import GoogleAdsCampaignsResponse as GoogleAdsCampaignsResponse
from flowhunt.models.google_ads_campaigns_search_request import GoogleAdsCampaignsSearchRequest as GoogleAdsCampaignsSearchRequest
from flowhunt.models.google_ads_customer_response import GoogleAdsCustomerResponse as GoogleAdsCustomerResponse
from flowhunt.models.google_ads_customer_update_request import GoogleAdsCustomerUpdateRequest as GoogleAdsCustomerUpdateRequest
from flowhunt.models.google_ads_customers_response import GoogleAdsCustomersResponse as GoogleAdsCustomersResponse
from flowhunt.models.google_ads_customers_search_request import GoogleAdsCustomersSearchRequest as GoogleAdsCustomersSearchRequest
from flowhunt.models.google_ads_group_response import GoogleAdsGroupResponse as GoogleAdsGroupResponse
from flowhunt.models.google_ads_group_status import GoogleAdsGroupStatus as GoogleAdsGroupStatus
from flowhunt.models.google_ads_group_update_request import GoogleAdsGroupUpdateRequest as GoogleAdsGroupUpdateRequest
from flowhunt.models.google_ads_groups_response import GoogleAdsGroupsResponse as GoogleAdsGroupsResponse
from flowhunt.models.google_ads_groups_search_request import GoogleAdsGroupsSearchRequest as GoogleAdsGroupsSearchRequest
from flowhunt.models.google_ads_keyword_add_request import GoogleAdsKeywordAddRequest as GoogleAdsKeywordAddRequest
from flowhunt.models.google_ads_keyword_recommendation import GoogleAdsKeywordRecommendation as GoogleAdsKeywordRecommendation
from flowhunt.models.google_ads_keyword_remove_request import GoogleAdsKeywordRemoveRequest as GoogleAdsKeywordRemoveRequest
from flowhunt.models.google_ads_match_type import GoogleAdsMatchType as GoogleAdsMatchType
from flowhunt.models.google_ads_recommendation import GoogleAdsRecommendation as GoogleAdsRecommendation
from flowhunt.models.google_ads_recommendation_confidence import GoogleAdsRecommendationConfidence as GoogleAdsRecommendationConfidence
from flowhunt.models.google_ads_recommendation_status import GoogleAdsRecommendationStatus as GoogleAdsRecommendationStatus
from flowhunt.models.google_ads_recommendation_type import GoogleAdsRecommendationType as GoogleAdsRecommendationType
from flowhunt.models.google_ads_recommendations_request import GoogleAdsRecommendationsRequest as GoogleAdsRecommendationsRequest
from flowhunt.models.google_calendar_response import GoogleCalendarResponse as GoogleCalendarResponse
from flowhunt.models.google_calendars_response import GoogleCalendarsResponse as GoogleCalendarsResponse
from flowhunt.models.google_picker_token_response import GooglePickerTokenResponse as GooglePickerTokenResponse
from flowhunt.models.google_sheet_response import GoogleSheetResponse as GoogleSheetResponse
from flowhunt.models.google_sheets_response import GoogleSheetsResponse as GoogleSheetsResponse
from flowhunt.models.http_validation_error import HTTPValidationError as HTTPValidationError
from flowhunt.models.health import Health as Health
from flowhunt.models.hub_spot_actor_id_response import HubSpotActorIdResponse as HubSpotActorIdResponse
from flowhunt.models.hub_spot_actors_response import HubSpotActorsResponse as HubSpotActorsResponse
from flowhunt.models.image_convert_request import ImageConvertRequest as ImageConvertRequest
from flowhunt.models.image_ft_create_request import ImageFTCreateRequest as ImageFTCreateRequest
from flowhunt.models.image_ft_response import ImageFTResponse as ImageFTResponse
from flowhunt.models.image_ft_search_request import ImageFTSearchRequest as ImageFTSearchRequest
from flowhunt.models.image_ft_update_request import ImageFTUpdateRequest as ImageFTUpdateRequest
from flowhunt.models.image_inference_request import ImageInferenceRequest as ImageInferenceRequest
from flowhunt.models.image_inference_response import ImageInferenceResponse as ImageInferenceResponse
from flowhunt.models.image_inference_result_response import ImageInferenceResultResponse as ImageInferenceResultResponse
from flowhunt.models.image_inference_schedule_response import ImageInferenceScheduleResponse as ImageInferenceScheduleResponse
from flowhunt.models.image_inference_scroll_response import ImageInferenceScrollResponse as ImageInferenceScrollResponse
from flowhunt.models.image_optimize_request import ImageOptimizeRequest as ImageOptimizeRequest
from flowhunt.models.image_prompt_generation_request import ImagePromptGenerationRequest as ImagePromptGenerationRequest
from flowhunt.models.image_prompt_response import ImagePromptResponse as ImagePromptResponse
from flowhunt.models.inference_file_type import InferenceFileType as InferenceFileType
from flowhunt.models.inference_history_search_request import InferenceHistorySearchRequest as InferenceHistorySearchRequest
from flowhunt.models.instagram_profile_information_response import InstagramProfileInformationResponse as InstagramProfileInformationResponse
from flowhunt.models.integration_category import IntegrationCategory as IntegrationCategory
from flowhunt.models.integration_detail_response import IntegrationDetailResponse as IntegrationDetailResponse
from flowhunt.models.integration_flow_response import IntegrationFlowResponse as IntegrationFlowResponse
from flowhunt.models.integration_response import IntegrationResponse as IntegrationResponse
from flowhunt.models.integration_search_request import IntegrationSearchRequest as IntegrationSearchRequest
from flowhunt.models.integration_slug import IntegrationSlug as IntegrationSlug
from flowhunt.models.langfuse_request import LangfuseRequest as LangfuseRequest
from flowhunt.models.log_entry_level import LogEntryLevel as LogEntryLevel
from flowhunt.models.log_entry_type import LogEntryType as LogEntryType
from flowhunt.models.log_response import LogResponse as LogResponse
from flowhunt.models.logs_search_request import LogsSearchRequest as LogsSearchRequest
from flowhunt.models.mcp_capability_binding import MCPCapabilityBinding as MCPCapabilityBinding
from flowhunt.models.mcp_server_create_request import MCPServerCreateRequest as MCPServerCreateRequest
from flowhunt.models.mcp_server_response import MCPServerResponse as MCPServerResponse
from flowhunt.models.mcp_server_search_request import MCPServerSearchRequest as MCPServerSearchRequest
from flowhunt.models.mcp_sub_server_binding import MCPSubServerBinding as MCPSubServerBinding
from flowhunt.models.message_type import MessageType as MessageType
from flowhunt.models.metadata import Metadata as Metadata
from flowhunt.models.observability_driver_response import ObservabilityDriverResponse as ObservabilityDriverResponse
from flowhunt.models.pagination import Pagination as Pagination
from flowhunt.models.photo_ai_effect_response import PhotoAIEffectResponse as PhotoAIEffectResponse
from flowhunt.models.photo_ai_style_response import PhotoAIStyleResponse as PhotoAIStyleResponse
from flowhunt.models.photo_ai_template_response import PhotoAITemplateResponse as PhotoAITemplateResponse
from flowhunt.models.plan_list_item_response import PlanListItemResponse as PlanListItemResponse
from flowhunt.models.plan_response import PlanResponse as PlanResponse
from flowhunt.models.pointer_type import PointerType as PointerType
from flowhunt.models.prompt_category_create_request import PromptCategoryCreateRequest as PromptCategoryCreateRequest
from flowhunt.models.prompt_category_response import PromptCategoryResponse as PromptCategoryResponse
from flowhunt.models.prompt_category_search_request import PromptCategorySearchRequest as PromptCategorySearchRequest
from flowhunt.models.prompt_category_update_request import PromptCategoryUpdateRequest as PromptCategoryUpdateRequest
from flowhunt.models.prompt_create_request import PromptCreateRequest as PromptCreateRequest
from flowhunt.models.prompt_response import PromptResponse as PromptResponse
from flowhunt.models.prompt_search_request import PromptSearchRequest as PromptSearchRequest
from flowhunt.models.prompt_update_request import PromptUpdateRequest as PromptUpdateRequest
from flowhunt.models.query_similarity_request import QuerySimilarityRequest as QuerySimilarityRequest
from flowhunt.models.query_similarity_task_request import QuerySimilarityTaskRequest as QuerySimilarityTaskRequest
from flowhunt.models.role import Role as Role
from flowhunt.models.saml_login_method import SamlLoginMethod as SamlLoginMethod
from flowhunt.models.schedule_create_request import ScheduleCreateRequest as ScheduleCreateRequest
from flowhunt.models.schedule_frequency import ScheduleFrequency as ScheduleFrequency
from flowhunt.models.schedule_response import ScheduleResponse as ScheduleResponse
from flowhunt.models.schedule_search_request import ScheduleSearchRequest as ScheduleSearchRequest
from flowhunt.models.schedule_status import ScheduleStatus as ScheduleStatus
from flowhunt.models.schedule_type import ScheduleType as ScheduleType
from flowhunt.models.schedule_update_request import ScheduleUpdateRequest as ScheduleUpdateRequest
from flowhunt.models.schedule_url_detail_response import ScheduleUrlDetailResponse as ScheduleUrlDetailResponse
from flowhunt.models.schedule_url_response import ScheduleUrlResponse as ScheduleUrlResponse
from flowhunt.models.schedule_url_search_request import ScheduleUrlSearchRequest as ScheduleUrlSearchRequest
from flowhunt.models.screenshot_request import ScreenshotRequest as ScreenshotRequest
from flowhunt.models.screenshot_response import ScreenshotResponse as ScreenshotResponse
from flowhunt.models.secret_create_request import SecretCreateRequest as SecretCreateRequest
from flowhunt.models.secret_response import SecretResponse as SecretResponse
from flowhunt.models.secret_search_request import SecretSearchRequest as SecretSearchRequest
from flowhunt.models.secret_update_request import SecretUpdateRequest as SecretUpdateRequest
from flowhunt.models.serp_cluster_add_query_request import SerpClusterAddQueryRequest as SerpClusterAddQueryRequest
from flowhunt.models.serp_cluster_add_query_requests import SerpClusterAddQueryRequests as SerpClusterAddQueryRequests
from flowhunt.models.serp_cluster_best_groups_request import SerpClusterBestGroupsRequest as SerpClusterBestGroupsRequest
from flowhunt.models.serp_cluster_group_intersections_request import SerpClusterGroupIntersectionsRequest as SerpClusterGroupIntersectionsRequest
from flowhunt.models.serp_cluster_group_search_request import SerpClusterGroupSearchRequest as SerpClusterGroupSearchRequest
from flowhunt.models.serp_cluster_group_sub_clusters_request import SerpClusterGroupSubClustersRequest as SerpClusterGroupSubClustersRequest
from flowhunt.models.serp_cluster_keyword_intersections_request import SerpClusterKeywordIntersectionsRequest as SerpClusterKeywordIntersectionsRequest
from flowhunt.models.serp_cluster_keyword_response import SerpClusterKeywordResponse as SerpClusterKeywordResponse
from flowhunt.models.serp_group_intersection import SerpGroupIntersection as SerpGroupIntersection
from flowhunt.models.serp_keyword import SerpKeyword as SerpKeyword
from flowhunt.models.serp_keyword_relation import SerpKeywordRelation as SerpKeywordRelation
from flowhunt.models.serp_query_request import SerpQueryRequest as SerpQueryRequest
from flowhunt.models.serp_search_engine_type import SerpSearchEngineType as SerpSearchEngineType
from flowhunt.models.serp_search_request import SerpSearchRequest as SerpSearchRequest
from flowhunt.models.serp_search_requests import SerpSearchRequests as SerpSearchRequests
from flowhunt.models.serp_subcluster_keywords_response import SerpSubclusterKeywordsResponse as SerpSubclusterKeywordsResponse
from flowhunt.models.serp_volume_request import SerpVolumeRequest as SerpVolumeRequest
from flowhunt.models.shop_redact_payload import ShopRedactPayload as ShopRedactPayload
from flowhunt.models.slack_channel_response import SlackChannelResponse as SlackChannelResponse
from flowhunt.models.slack_workspace_response import SlackWorkspaceResponse as SlackWorkspaceResponse
from flowhunt.models.sort_direction import SortDirection as SortDirection
from flowhunt.models.subscription_plan import SubscriptionPlan as SubscriptionPlan
from flowhunt.models.tag_create_request import TagCreateRequest as TagCreateRequest
from flowhunt.models.tag_response import TagResponse as TagResponse
from flowhunt.models.tag_search_request import TagSearchRequest as TagSearchRequest
from flowhunt.models.tag_update_request import TagUpdateRequest as TagUpdateRequest
from flowhunt.models.task_response import TaskResponse as TaskResponse
from flowhunt.models.task_status import TaskStatus as TaskStatus
from flowhunt.models.tracking_click_id_names import TrackingClickIdNames as TrackingClickIdNames
from flowhunt.models.tracking_event_create_request import TrackingEventCreateRequest as TrackingEventCreateRequest
from flowhunt.models.tracking_event_create_requests import TrackingEventCreateRequests as TrackingEventCreateRequests
from flowhunt.models.tracking_event_data import TrackingEventData as TrackingEventData
from flowhunt.models.tracking_event_response import TrackingEventResponse as TrackingEventResponse
from flowhunt.models.tracking_event_search_request import TrackingEventSearchRequest as TrackingEventSearchRequest
from flowhunt.models.tracking_events_response import TrackingEventsResponse as TrackingEventsResponse
from flowhunt.models.tracking_link_create_request import TrackingLinkCreateRequest as TrackingLinkCreateRequest
from flowhunt.models.tracking_link_response import TrackingLinkResponse as TrackingLinkResponse
from flowhunt.models.tracking_link_search_request import TrackingLinkSearchRequest as TrackingLinkSearchRequest
from flowhunt.models.tracking_links_create_request import TrackingLinksCreateRequest as TrackingLinksCreateRequest
from flowhunt.models.tracking_links_response import TrackingLinksResponse as TrackingLinksResponse
from flowhunt.models.tracking_source_create_request import TrackingSourceCreateRequest as TrackingSourceCreateRequest
from flowhunt.models.tracking_source_response import TrackingSourceResponse as TrackingSourceResponse
from flowhunt.models.tracking_source_search_request import TrackingSourceSearchRequest as TrackingSourceSearchRequest
from flowhunt.models.tracking_source_types import TrackingSourceTypes as TrackingSourceTypes
from flowhunt.models.tracking_sources_response import TrackingSourcesResponse as TrackingSourcesResponse
from flowhunt.models.transaction_type import TransactionType as TransactionType
from flowhunt.models.transcript_task_request import TranscriptTaskRequest as TranscriptTaskRequest
from flowhunt.models.trigger_response import TriggerResponse as TriggerResponse
from flowhunt.models.trigger_type import TriggerType as TriggerType
from flowhunt.models.url_screenshot_response import UrlScreenshotResponse as UrlScreenshotResponse
from flowhunt.models.user_document_status import UserDocumentStatus as UserDocumentStatus
from flowhunt.models.user_plan_response import UserPlanResponse as UserPlanResponse
from flowhunt.models.user_response import UserResponse as UserResponse
from flowhunt.models.validation_error import ValidationError as ValidationError
from flowhunt.models.validation_error_loc_inner import ValidationErrorLocInner as ValidationErrorLocInner
from flowhunt.models.vector_document_response import VectorDocumentResponse as VectorDocumentResponse
from flowhunt.models.vector_document_type import VectorDocumentType as VectorDocumentType
from flowhunt.models.vector_documents_task_response import VectorDocumentsTaskResponse as VectorDocumentsTaskResponse
from flowhunt.models.word_press_category_response import WordPressCategoryResponse as WordPressCategoryResponse
from flowhunt.models.word_press_site_response import WordPressSiteResponse as WordPressSiteResponse
from flowhunt.models.word_press_tags_response import WordPressTagsResponse as WordPressTagsResponse
from flowhunt.models.workspace_create_request import WorkspaceCreateRequest as WorkspaceCreateRequest
from flowhunt.models.workspace_response import WorkspaceResponse as WorkspaceResponse
from flowhunt.models.workspace_role import WorkspaceRole as WorkspaceRole
from flowhunt.models.workspace_sso_create_request import WorkspaceSSOCreateRequest as WorkspaceSSOCreateRequest
from flowhunt.models.workspace_sso_domain_verification_create_request import WorkspaceSSODomainVerificationCreateRequest as WorkspaceSSODomainVerificationCreateRequest
from flowhunt.models.workspace_sso_domain_verification_response import WorkspaceSSODomainVerificationResponse as WorkspaceSSODomainVerificationResponse
from flowhunt.models.workspace_sso_list_response import WorkspaceSSOListResponse as WorkspaceSSOListResponse
from flowhunt.models.workspace_sso_response import WorkspaceSSOResponse as WorkspaceSSOResponse
from flowhunt.models.workspace_sso_update_request import WorkspaceSSOUpdateRequest as WorkspaceSSOUpdateRequest
from flowhunt.models.workspace_search_request import WorkspaceSearchRequest as WorkspaceSearchRequest
from flowhunt.models.workspace_update_request import WorkspaceUpdateRequest as WorkspaceUpdateRequest
from flowhunt.models.workspace_user_create_request import WorkspaceUserCreateRequest as WorkspaceUserCreateRequest
from flowhunt.models.workspace_user_response import WorkspaceUserResponse as WorkspaceUserResponse
from flowhunt.models.workspace_user_update_request import WorkspaceUserUpdateRequest as WorkspaceUserUpdateRequest
from flowhunt.models.workspace_users_search_request import WorkspaceUsersSearchRequest as WorkspaceUsersSearchRequest
from flowhunt.models.youtube_content import YoutubeContent as YoutubeContent
from flowhunt.models.youtube_transcript_request import YoutubeTranscriptRequest as YoutubeTranscriptRequest
from flowhunt.models.youtube_transcript_response import YoutubeTranscriptResponse as YoutubeTranscriptResponse



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.google_ads_api import GoogleAdsApi


class TestGoogleAdsApi(unittest.TestCase):
    """GoogleAdsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GoogleAdsApi()

    def tearDown(self) -> None:
        pass

    def test_add_keyword_to_group(self) -> None:
        """Test case for add_keyword_to_group

        Add Keyword To Group
        """
        pass

    def test_analyze_not_assigned_keywords(self) -> None:
        """Test case for analyze_not_assigned_keywords

        Analyze Not Assigned Keywords
        """
        pass

    def test_get_google_ads_campaigns(self) -> None:
        """Test case for get_google_ads_campaigns

        Get Google Ads Campaigns
        """
        pass

    def test_get_google_ads_customers(self) -> None:
        """Test case for get_google_ads_customers

        Get Google Ads Customers
        """
        pass

    def test_get_google_ads_groups(self) -> None:
        """Test case for get_google_ads_groups

        Get Google Ads Groups
        """
        pass

    def test_get_recommendations(self) -> None:
        """Test case for get_recommendations

        Get Recommendations
        """
        pass

    def test_import_google_ads_campaigns(self) -> None:
        """Test case for import_google_ads_campaigns

        Import Google Ads Campaigns
        """
        pass

    def test_import_google_ads_customers(self) -> None:
        """Test case for import_google_ads_customers

        Import Google Ads Customers
        """
        pass

    def test_import_google_ads_groups(self) -> None:
        """Test case for import_google_ads_groups

        Import Google Ads Groups
        """
        pass

    def test_remove_keyword_from_group(self) -> None:
        """Test case for remove_keyword_from_group

        Remove Keyword From Group
        """
        pass

    def test_update_google_ads_campaign(self) -> None:
        """Test case for update_google_ads_campaign

        Update Google Ads Campaign
        """
        pass

    def test_update_google_ads_customer_update(self) -> None:
        """Test case for update_google_ads_customer_update

        Update Google Ads Customer Update
        """
        pass

    def test_update_google_ads_group(self) -> None:
        """Test case for update_google_ads_group

        Update Google Ads Group
        """
        pass


if __name__ == '__main__':
    unittest.main()
